==> nonos-0.11.0-py3-none-any.whl: nonos/_backports.py <==
import sys

if sys.version_info >= (3, 11):
    pass
else:
    from enum import Enum

    # vendored from Python 3.11.0
    class ReprEnum(Enum):
        """
        Only changes the repr(), leaving str() and format() to the mixed-in type.
        """

    class StrEnum(str, ReprEnum):
        """
        Enum where members are also (and must be) strings
        """

        def __new__(cls, *values):
            "values must already be of type `str`"
            if len(values) > 3:
                raise TypeError(f"too many arguments for str(): {values!r}")
            if len(values) == 1:
                # it must be a string
                if not isinstance(values[0], str):
                    raise TypeError(f"{values[0]!r} is not a string")
            if len(values) >= 2:
                # check that encoding argument is a string
                if not isinstance(values[1], str):
                    raise TypeError(f"encoding must be a string, not {values[1]!r}")
            if len(values) == 3:
                # check that errors argument is a string
                if not isinstance(values[2], str):
                    raise TypeError("errors must be a string, not %r" % (values[2]))
            value = str(*values)
            member = str.__new__(cls, value)
            member._value_ = value
            return member

        def _generate_next_value_(name, start, count, last_values):  # noqa: ARG002
            """
            Return the lower-cased version of the member name.
            """
            return name.lower()

==> nonos-0.13.1-py3-none-any.whl: nonos/_backports.py <==
import sys

if sys.version_info >= (3, 9):
    pass
else:

    def removeprefix(base: str, prefix: str) -> str:
        if base.startswith(prefix):
            return base[len(prefix) :]
        else:
            return base

    def removesuffix(base: str, suffix: str) -> str:
        if base.endswith(suffix):
            return base[: len(base) - len(suffix)]
        else:
            return base


if sys.version_info >= (3, 11):
    pass
else:
    from enum import Enum

    # vendored from Python 3.11.0
    class ReprEnum(Enum):
        """
        Only changes the repr(), leaving str() and format() to the mixed-in type.
        """

    class StrEnum(str, ReprEnum):
        """
        Enum where members are also (and must be) strings
        """

        def __new__(cls, *values):
            "values must already be of type `str`"
            if len(values) > 3:
                raise TypeError(f"too many arguments for str(): {values!r}")
            if len(values) == 1:
                # it must be a string
                if not isinstance(values[0], str):
                    raise TypeError(f"{values[0]!r} is not a string")
            if len(values) >= 2:
                # check that encoding argument is a string
                if not isinstance(values[1], str):
                    raise TypeError(f"encoding must be a string, not {values[1]!r}")
            if len(values) == 3:
                # check that errors argument is a string
                if not isinstance(values[2], str):
                    raise TypeError("errors must be a string, not %r" % (values[2]))
            value = str(*values)
            member = str.__new__(cls, value)
            member._value_ = value
            return member

        def _generate_next_value_(name, start, count, last_values):  # noqa: ARG002
            """
            Return the lower-cased version of the member name.
            """
            return name.lower()
